==> FHLBBS-5.3.tgz: php/config.php <==
<?php
/***** define share memory key ************/
$UIDSHM_KEY=1217;         //user share memory key
$BRDSHM_KEY=1215;	  //BOARD share memory key
$HOME="/home/bbs/home/"; //USER home file
$PASSWD_FILE="/home/bbs/.PASSWDS"; //password file
$WFN_USIES="/home/bbs/wusies";    /* WBBS log */
$MAXUSERS=16000 ;  	//̰UH
$MAXBOARD=256 ;         /* ̤j}Ӽ */
$BBSHOME="/home/bbs"; //BBS home
$dirlength=128;
/*******峹Ҧ***********/
$FILE_READ=1;	//local saved
$FILE_LOCAL=1;  //already read : mail only
$FILE_MARKED=2; //market?
$FILE_DIGEST=4; //digest
$FILE_TAGED=8;  //taged
$fn_overrides  = "overrides" ; //wqnͦWɮ
$str_space         = " \t\n\r";
$SHOWNUM   = 20; 	//@20
$doorid=0; //Ψӳ]whjALثe]w@j
$FNLEN = 33;      //]wQװϻPHɮצW٪
$DEFAULT_BOARD="W_sysop"; //wQװ
$END_TITLE="\n--\n     Origin: HR(wbbs.fhl.net) "; //]w峹
$fn_plans          = "plans";	//PLANSɦW
$BRC_MAXSIZE =     24576;  //QװϾ\Ṳ̄j
$BRC_STRLEN = 15;	   //QװϾ\ŪAQװϦWr
$BRC_MAXNUM =     80;      //C@ӰQװϳ̦hXg\Ū
$BRC_ITEMSIZE=$BRC_STRLEN + 1 + $BRC_MAXNUM * 4; //@QװϾ\Ṳ̄ji
//$NOGUEST=0;		   //]w@몺pUAĤ@iJOguest
$INTRODUCE = "introduce";	//ۧڤаQװ
$MAX_NOTE  =10 ; 		//Qӯd
$TALKNUM  =7 ;          //talk OdQtalk
$CHATNUM  =17 ;                 //talk OdQtalk
$CHATDIR="/home/bbs/chat";      //CHAT u@ؿ
$MYFILE="mybbs";		//MY BBS\Ϊɮ
$BTLEN=48;			//D

/****** Login ᪺Ѽ *******/
$DEFDIR=array("/home/bbs/pwbbs/",     //eҦbؿ
              "/home/bbs/wbbs1/"
             ); 
$prefile=array("postpre.html", 		//sQװϱiK峹Y
               "replypre.html", 	//sQװϦ^峹Y
               "reauthpre.html",	//^H峹@
               "mailpre.html",  	//sHH峹Y
               "remailpre.html");	//s^H峹Y

$MAINFUNC="main.html"; 		//LOGIN De
$GIFNUM="/etc/gifnum";    	//ɼƥ
$HTMLNUM="/etc/htmlnum";  	//HTMLsiɼƥ
$BLISTPRE= "predef.txt"; 	//QװϦCY
$CLASSLISTPRE= "classdef.txt"; 	//QװϦCY
$BOARDPRE="listdef.txt";        //峹CY
$BOARDDELPRE="listdeldef.txt";  //R峹CY
$MREADDEF="mreaddef.txt";       //H\ŪY
$READPRE="readdef.txt"; 	//\ŪeY
$MLISTDEF= "mlistdef.txt"; 	//HCY
$MDELDEF= "mdeldef.txt";   	//H󪺪Y
$LOGOUTMENU= "logout.html";     //e
$USEREDIT = "useredit.txt"; //ϥΪ̸ƭקﱱ
$MAINB =  "main_b.html";        //WiJQװϪDe

?>

==> FHLBBS-5.4.tgz: php/config.php <==
<?php
/***** define share memory key ************/
$UIDSHM_KEY=1217;         //user share memory key
$BRDSHM_KEY=1215;	  //BOARD share memory key
$HOME="/home/bbs/home/"; //USER home file
$PASSWD_FILE="/home/bbs/.PASSWDS"; //password file
$WFN_USIES="/home/bbs/wusies";    /* WBBS log */
$MAXUSERS=16000 ;  	//̰UH
$MAXBOARD=256 ;         /* ̤j}Ӽ */
$BBSHOME="/home/bbs"; //BBS home
$dirlength=128;
$upload_dir="/home/bbs/media/"; //峹WǥΪؿ
$upload_url="/media/"; //峹WǥΪؿ
/*******峹Ҧ***********/
$FILE_READ=1;	//local saved
$FILE_LOCAL=1;  //already read : mail only
$FILE_MARKED=2; //market?
$FILE_DIGEST=4; //digest
$FILE_TAGED=8;  //taged
$fn_overrides  = "overrides" ; //wqnͦWɮ
$str_space         = " \t\n\r";
$SHOWNUM   = 20; 	//@20
$doorid=0; //Ψӳ]whjALثe]w@j
$FNLEN = 33;      //]wQװϻPHɮצW٪
$DEFAULT_BOARD="sysop"; //wQװ
$END_TITLE="\n--\n     Origin: HR(wbbs.fhl.net) "; //]w峹
$fn_plans          = "plans";	//PLANSɦW
$BRC_MAXSIZE =     24576;  //QװϾ\Ṳ̄j
$BRC_STRLEN = 15;	   //QװϾ\ŪAQװϦWr
$BRC_MAXNUM =     80;      //C@ӰQװϳ̦hXg\Ū
$BRC_ITEMSIZE=$BRC_STRLEN + 1 + $BRC_MAXNUM * 4; //@QװϾ\Ṳ̄ji
//$NOGUEST=0;		   //]w@몺pUAĤ@iJOguest
$INTRODUCE = "introduce";	//ۧڤаQװ
$MAX_NOTE  =10 ; 		//Qӯd
$TALKNUM  =7 ;          //talk OdQtalk
$CHATNUM  =17 ;                 //talk OdQtalk
$CHATDIR="/home/bbs/chat";      //CHAT u@ؿ
$MYFILE="mybbs";		//MY BBS\Ϊɮ
$BTLEN=48;			//D
$tcolor[0] = " bgcolor=\"#DDDDDD\""; //CC
$tcolor[1] = "";                    //CC


/****** Login ᪺Ѽ hjΪ *******/
if (strcmp($HTTP_HOST,"nbbs.fhl.net")==0)
{
  $DEFDIR=array("/home/bbs/pwbbs/",     //eҦbؿ
             );
}
elseif (strcmp($HTTP_HOST,"rbbs.fhl.net")==0)
{
  $DEFDIR=array("/home/bbs/rwbbs/",     //eҦbؿ
             );
}
else //wj
{
  $DEFDIR=array("/home/bbs/qwbbs/",     //eҦbؿ
             ); 
}
$prefile=array("postpre.html", 		//sQװϱiK峹Y
               "replypre.html", 	//sQװϦ^峹Y
               "reauthpre.html",	//^H峹@
               "mailpre.html",  	//sHH峹Y
               "remailpre.html");	//s^H峹Y

$MAINFUNC="main.html"; 		//LOGIN De
$GIFNUM="/etc/gifnum";    	//ɼƥ
$HTMLNUM="/etc/htmlnum";  	//HTMLsiɼƥ
$BLISTPRE= "predef.txt"; 	//QװϦCY
$CLASSLISTPRE= "classdef.txt"; 	//QװϦCY
$BOARDPRE="listdef.txt";        //峹CY
$BOARDDELPRE="listdeldef.txt";  //R峹CY
$MREADDEF="mreaddef.txt";       //H\ŪY
$READPRE="readdef.txt"; 	//\ŪeY
$MLISTDEF= "mlistdef.txt"; 	//HCY
$MDELDEF= "mdeldef.txt";   	//H󪺪Y
$LOGOUTMENU= "logout.html";     //e
$USEREDIT = "useredit.txt"; //ϥΪ̸ƭקﱱ
$MAINB =  "main_b.html";        //WiJQװϪDe
$post_html_member=array("fhlwww"); //]widiHpost html|QdI
#$post_html_member=array("tjm"); //]widiHpost html|QdI
?>
